### A Pluto.jl notebook ###
# v0.20.4

using Markdown
using InteractiveUtils

# This Pluto notebook uses @bind for interactivity. When running this notebook outside of Pluto, the following 'mock version' of @bind gives bound variables a default value (instead of an error).
macro bind(def, element)
    #! format: off
    quote
        local iv = try Base.loaded_modules[Base.PkgId(Base.UUID("6e696c72-6542-2067-7265-42206c756150"), "AbstractPlutoDingetjes")].Bonds.initial_value catch; b -> missing; end
        local el = $(esc(element))
        global $(esc(def)) = Core.applicable(Base.get, el) ? Base.get(el) : iv(el)
        el
    end
    #! format: on
end

# ╔═╡ b72215bb-8e3a-46e2-8817-271befe1178c
begin
	using HypertextLiteral, PlutoUI, PlutoPlotly, PlotlyKaleido
	using Dates, DataFrames, CSV, Statistics, LinearAlgebra, NLsolve
end

# ╔═╡ 49b0122c-eb23-4cab-a49d-077fb76b53df
html"""
<picture>
  <source srcset="https://gci.iscte-iul.pt/2022/identidade/files/brand_v2/escolas/rgb/ibs/en/horizontal/negative/rgb_ibs_en_horizontal_negative.png" media="(prefers-color-scheme: dark)" width="240px!important" style="float:right;">
  <img src=""http://modernmacro.org/resources/Vivaldo/figures/iscte.png" width="240px" style="float:right;">
</picture>
"""

# ╔═╡ 82090c38-1ecd-43eb-aeca-135d996b8e72
md"""
# Week 1 - Welcome to Pluto Notebooks

## Introduction to Pluto

**Macroeconomics, ISCTE-IUL**
"""

# ╔═╡ 76164b77-2e0b-4deb-8ef8-1b2263260e7a
md"""
**Vivaldo Mendes, Ricardo Gouveia-Mendes, Luís Clemente-Casinhas**

**February 2025**
"""

# ╔═╡ f5e8df36-5568-48ca-a0f8-d118f49edc6c
md"""
---
"""

# ╔═╡ 554b2cc5-99e1-4eda-b080-67ab2eddac16
md"""
### Packages used in this notebook
"""

# ╔═╡ f270f189-2838-4827-9c53-aef5f4f678d4
md"""
---
"""

# ╔═╡ 31023dd0-f304-471e-a292-2a40915ebcbf
md"""
## 1. What is a Pluto notebook?
"""

# ╔═╡ 7afb249a-ee89-4874-91fa-6da606948b2a
md"""
A notebook is a document with two types of cells (see image below): 
- code cells
- markdown cells 

The first type of cells includes computational code, short comments, and Pluto's "begin-end" blocks. Code cells produce an output, which usually takes the form of a plot, a table, numbers, or symbols.

The second type of cell (markdown) allows for the writing of standard text, mathematics, and inserting an image or a video, among other functionalities. 

The versatility that arises from combining markdown cells with code cells makes notebooks a remarkable tool for computational work in general and teaching in particular. The following image provides an overview of most elements composing a notebook. They will be explained in more detail in the next section.
"""

# ╔═╡ cbaf6be3-ce2e-424f-9eba-2afdb0f024fe
Resource("https://vivaldomendes.org/images/depot/Pluto_cells.png", :width=>820)

# ╔═╡ 86f1359d-3637-4892-9720-e042fae6543a
md"""
____________________________________________________________________________________________________________
"""

# ╔═╡ 0fc80d2d-6519-4f17-83c4-25ab9b26d8ce
md"""
## 2. Pluto basic tips
"""

# ╔═╡ 16ecc97b-a401-4172-bcbb-b0baa156b53c
md"""
### Opening a new cell
"""

# ╔═╡ 564ff460-aa1f-4b9d-abf3-a024a13d96a3
md"""

- Put the mouse on top of any opened/visible cell. 
- You will see a $+$ sign in the top and bottom left corners (**_see image below_**).
- Click on the $+$ sign where you want the new cell to be placed.
"""

# ╔═╡ ca0b5757-4521-4d4b-b46f-76b8dfdc2d62
Resource("https://modernmacro.org/resources/vivaldo/figures/Pluto_basic_tips_Edited.png", :width=>900)

# ╔═╡ 6307472b-3a3e-4d9a-82fd-25d295abaae1
md"""
### How to run a cell?

- See **_image above_**
- Click on the small circle-arrow in the bottom right-hand-side of each cell (▶)
- Or, click simultaneosly on **Shift** and **Enter**

"""

# ╔═╡ 638ac59a-6fb2-447f-8856-0c6f74494e7b
md"""
### How to save a notebook?

- When a cell is run, this action will be automatically saved
- If we forget to run a particular cell, click simultaneously on **Ctrl** and **s** to save all changes that may have been implemented and not yet saved.

"""

# ╔═╡ 47c0ad5a-3c9f-4b42-b353-c40ea704f404
md"""
### Code cells
"""

# ╔═╡ 364250da-5811-4e15-9f88-e408a99e83f3
md"""

- When we click on the $+$ sign, as shown above, a new cell will be automatically opened
- By default, this new cell will be a code cell
- The next cell is an empty code cell that can be used for computation. For example, type 2+2 and run it.

"""

# ╔═╡ 5eaac75d-b7aa-412e-bb73-ed4865cae27b
2+2

# ╔═╡ 98f18fc3-0748-4ec7-a6a0-955e2ea22e19
md"""
### Markdown cells
"""

# ╔═╡ e81d6184-2b39-4205-83a8-9e2d7e5d41dd
md"""
- If we want to write text or mathematics in a new cell, or insert a video, we have to turn it into a "markdown" cell
- To change a cell from code mode into **_markdown mode_**, put the cursor inside the cell you want to be in markdown.
  - Click on the following: **Ctrl** and **m** simultaneously. 
- That is all. You can start typing text or mathematics as you like.

"""

# ╔═╡ 70af87bd-81b5-4aa0-b1f7-0639d1f09d0a
md"""
!!! tip
	To write text in bold, italics, or mathematical symbols do the following: 
	- type: `**This is bold**` to get: **This is bold**
	- type: `_This is italics_` to get: _This is italics_
	- type: `**_This is bold and italics_**` to get: **_This is bold and italics_**
	- type: `$y=2x^2$` to get a mathematical expression: $y=2x^2$
"""

# ╔═╡ 2da4b605-2d9e-494a-810f-5d153dee7096
md"""
#### Bold and Italics
"""

# ╔═╡ 8c3253f4-86c2-4b88-9850-f7daed87774d
md"""
This is **bold**

This is _italics_

This is **_bold and italics_**

"""

# ╔═╡ dca08890-c8af-4a31-b7cd-bf27e9bd91b7
md"""
!!! note "Exercise 1"
 
	- Open a new cell and turn it into markdown mode. Write in this cell the following text: `Today is a sunny day!`
	- Open another cell, turn it into markdown mode, and write the same text but in bold, and also in italics.
	- Open a new cell, turn it into markdown mode, and write the following: This is text and mathematics with a funny equation $y = xz/2$
	- Open a new cell, turn it into markdown mode, and write the following equation: $y = 3x^2$
	
"""

# ╔═╡ a0280f97-cf3d-4aaf-a013-45d957bd5700
md"""
!!! tip "Answer"

	Insert your answers below this box.	 

"""

# ╔═╡ 5b3d0a21-ab5c-4b41-8824-eae02427a14c
md"""
Today is a sunny day!

**Today is a sunny day!**

_Today is a sunny day!_

$$y=xz/2$$

$$y=3x^2$$
"""

# ╔═╡ dfc08cee-92a3-43dd-a4be-e66a7a3ae4d9
md"""
____________________________________________________________________________________________________________
"""

# ╔═╡ 847ceec0-33cc-4cf4-a27f-ab7b85944529
md"""
## 3. Arithmetic operators
"""

# ╔═╡ 8f1bb867-1fa7-45e1-9806-70055ae22403
md"""

	+x	    unary plus	        the identity operation

	-x	    unary minus	      	maps values to their additive inverses

	x + y	binary plus	    	performs addition

	x - y	binary minus		performs subtraction

	x * y	times	        	performs multiplication

	x / y	divide	        	performs division

	x ÷ y	integer divide		x / y, truncated to an integer

	x \ y	inverse divide		equivalent to y / x

	x ^ y	power				raises x to the yth power

	x % y	remainder			equivalent to rem(x,y)'

"""

# ╔═╡ 4e908c09-f7eb-4698-9e9a-af1b7f7e5dc0
2+3

# ╔═╡ eea51a0b-cbe8-4fec-baec-ebc0601374d5
10^4

# ╔═╡ 731a0394-6dc6-44af-ada7-164fe8ed0c20
pepe = 10

# ╔═╡ 697cac78-ee49-48b7-9e7e-e6eace68cab9
rock = 20

# ╔═╡ abf827e7-0a9f-45e0-b89e-4b7ebaece273
mary = pepe * rock

# ╔═╡ b26522be-2c5e-4cd0-bfa2-eb20ff1f8070
md"""
`fiona = `$(@bind fiona Slider(-5.0:0.5:5.0, default=1.0, show_value=true))
"""

# ╔═╡ f01ee3cf-674b-41e2-8615-aebacb9ba384
paty = (fiona * mary , fiona^2 , fiona*mary , 10*fiona)

# ╔═╡ 26c4d01b-729e-4629-90a8-1e91247d0dff
md"""
!!! note "Exercise 2"
 
	What is the value of a variable called "zazu", given the following equation?

	$$zazu = 10 + rock^2 + \frac{pepe}{2}$$
"""

# ╔═╡ 44eadb1a-e4e2-4e62-a2b5-c29d11e9dc40
zazu = 10 + rock^2 + pepe/2

# ╔═╡ 9d6a33a0-72c5-4c36-b1be-fa17996ceda9
md"""
!!! tip "Answer"

	zazu = 415.	 	 

"""

# ╔═╡ b0ef4ed2-8236-4809-a508-74fee43f4bb2
md"""
____________________________________________________________________________________________________________
"""

# ╔═╡ 9b622087-ad34-4f19-9929-cbdf0256eae0
md"""
## 4. Magic things we can do with Pluto
"""

# ╔═╡ b8b7733f-d8ea-48d9-a24a-a938dc83f641
md"""
### Fancy symbols for writing text and doing computation
"""

# ╔═╡ af94fe17-19e7-418d-90a8-6e76ecfbfb29
md"""
I have a 😺 that loves the 🌚, but not 🍍. With these adorable objects, I can write simple text or do computations. 
"""

# ╔═╡ a1011eff-d753-437a-8139-925cef00f188
md"""
!!! tip
	To write special characters (like beta, for example) do the following: 
	- type: `\beta` and then click on `Tab` key to obtain β
	  - The firt time you do it, you have to click more than once on the `Tab` key. After that, clicking only once will be enough.
	- type: `\:smile` and then click on `Tab` to obtain 😄

	- type: `\:apple` and then click on `Tab` to obtain 🍎
"""

# ╔═╡ d4b64810-d65f-45ea-9037-bb2e57ff8811
β = 3

# ╔═╡ 70a5fdbe-17fa-4766-9c30-ab97113507b9
α = 10 * β

# ╔═╡ e1474fb7-6814-4294-b752-b0156db225f2
β^2

# ╔═╡ ee6330b0-efb8-4714-9957-5aeddce0867b
🍎=5

# ╔═╡ 975dd1ad-7989-40d1-9374-322da6dde414
2*🍎

# ╔═╡ a4f1fff1-2e34-4b40-81b0-899a5012fb64
😃 = 500

# ╔═╡ 8325bf62-e34f-429f-9c5a-c3a994e4d6ee
🍎*🍎 / (2*😃)

# ╔═╡ 7eaf19e5-f205-485d-82a8-48fc1987df33
md"""
!!! note "Exercise 3"
 
	- Open a new cell and turn it into markdown mode. 
	- Write in this cell the following symbols (beta, psi, theta): β ψ θ
"""

# ╔═╡ edd2845f-2da7-49b8-a509-f2bfa391c7cb
md"""
β ψ θ 
"""

# ╔═╡ c39ba17f-5894-4bc4-b6aa-f6f39947dc59
md"""
____________________________________________________________________________________________________________
"""

# ╔═╡ 5b28585a-29ef-4de8-91a9-7dd9fd559515
md"""
### Play with sliders
"""

# ╔═╡ 1dfab317-6e41-4c11-a811-683f0fd897b4
md"""
!!! note "Exercise 4"
 
	Move the two sliders below (one slide at a time), and see what happens to the equilibrium in the plot above.
"""

# ╔═╡ d06b313f-d6c0-45bc-96f5-7514c9765f81
md"""
!!! tip "Answer"

	If we change the sliders, the equilibrium at point 1 will be changed.  	 	 

"""

# ╔═╡ 1026f60d-0d2b-465b-a342-5a79af8131eb
md"""
---
"""

# ╔═╡ 86249e98-7e54-4e42-a02f-ab5af6120194
md"""
!!! note "Exercise 5"
 
	Move the two sliders below (one slide at a time), and see what happens to the sinusoidal wave below.
"""

# ╔═╡ ca2c2c20-acd6-49bf-b7e0-86590cc12b46
md"""
---
"""

# ╔═╡ 98fcb7b2-4d54-4119-a8ea-9545bea129e3
md"""
!!! note "Exercise 6"
 
	We can estimate the integral of a function $F:[a,b] \rightarrow \mathbb{R}$ using the midpoint rule approximation. Let us interactively estimate the $\int_0^1 F(x) d x$ to see the effect of changing the number of subintervals, in the case of:

	$$F(x)= - xsin(2\pi x)$$
"""

# ╔═╡ 4dc03487-e364-43e7-ba4a-e88ac9344089
begin
	Nbins_slider = @bind Nbins html"<input type=range min=1 max=400 step=1 value=20>"
		
	md"""Number of intervals: $Nbins_slider"""
end

# ╔═╡ fa2bb866-fac3-481c-837b-a8425fe84160
let
	F(x)=-x*sin(2π*x) 
	centres=1/(2*Nbins):1/Nbins:1
	midpointarea=round(sum(F.(centres))/Nbins, digits=6)
	
	trace01 = bar(x=centres, y=F.(centres), kind="bar", name = "Area")
	trace02 = scatter(x=centres, y= .- centres .* sin.(2 .* π .* centres), name = "F(x)")
		
	plot([trace01, trace02], Layout(height = 450, title_text="midpoint rule approximation with $Nbins intervals = $midpointarea"))
end

# ╔═╡ 72e56a5d-acf3-494d-b870-7806855eb74c
md"""
!!! tip "Answer"

	The solution is very, very close to 0.159157.  	 	 

"""

# ╔═╡ 09a44240-57a1-4064-9048-406cf4073cb9
md"""
____________________________________________________________________________________________________________
"""

# ╔═╡ cd0cd247-d257-49b1-a43b-f548a6062e36
md"""
### Playing with questions & answers 
"""

# ╔═╡ 987351ec-a397-4d67-a33f-967cd3464913
md"""
!!! note "Exercise 7"
 
	Table 1 shows some important macroeconomic aggregates, measured in **_real values_**, for the US economy in 2013 (do not worry about the term _real values_, we will clarify it in week 3). The data displayed in this table has been inserted into the notebook (see cell below the table). Answer question 👉 **a)** using the Hint. 
"""

# ╔═╡ 5045c5ff-6ec3-4d4a-b076-5356c39c3355
md"""
$$\begin{aligned}
& \text {Table 1. Expenditure in the USA in 2013}\\
&\begin{array}{cllr}
\hline \hline \text {  } & \text{Code} & \text {Headings} & \text {Billions of dollars} \\
\hline  
1 & cons & \text{Private Consumption Expenditures} & 11400 &  \\
2 & inve & \text{Investment in Equipment and Structures} & 2600 &  \\
3 & stoc & \text{Inventories} & 80 &  \\
4 & gove & \text{Public Consumption Expenditures} & 3120 &  \\
5 & expo & \text{Exports} & 2250 &  \\
6 & impo & \text{Imports} & 3000 &  \\

\hline
\end{array}
\end{aligned}$$

"""

# ╔═╡ 4930d23c-d101-4c36-b2f6-d6b8ddca1dc0
# values passed into the notebook
cons = 11400 ; inve = 2600 ; stoc = 80 ; gove = 3120 ; expo = 2250 ; impo = 3000 ;

# ╔═╡ 30e9b082-c43d-4f5b-b5bc-c5038e121dc6
md"""
👉 **a)** Using Table 1, calculate GDP by the expenditure method. 
"""

# ╔═╡ a11ee5f4-6790-4a96-8ee0-3c6b7ef0198e
md"""
!!! hint

	In week 3, you will learn that according to the usual definition of GDP by the expenditure method, GDP equals the sum of private consumption plus public consumption, plus investment and inventories, and plus exports minus imports.
"""

# ╔═╡ d2cd2672-83a0-4488-80e9-0c54c064b19d
gdp = cons + inve + stoc + gove + expo - impo

# ╔═╡ 1818b565-dbd0-438b-9a69-0815b8013675
md"""
!!! tip "Answer (a) "

	GDP was equal to 16450 billion dollars in 2013.

"""

# ╔═╡ 22d3f12d-753b-4062-a6ee-53e3af16674a
md"""
---
"""

# ╔═╡ 2b457972-3c5d-4421-90df-42c09d0d68c8
md"""
!!! note "Exercise 8"
 
	We can use Pluto to create multiple-choice questions with some pedagogic feedback. Try to answer the following question using the bullets below. **_Do not worry about the fact that you may not know the correct answer at this moment. We are just practicing with Pluto._**

"""

# ╔═╡ afca4d98-7fe9-4123-b130-d3f5b3813db0
md"""
How much did the US GDP change in 2023, given the following facts:

- First Republic Bank shareholders lost 2 billion dollars on March 16 due to the bank's collapse.

- Microsoft decided to invest 10 billion dollars in the development of ChatGPT (OpenAI). 

- Amazon bought 100% of the capital of the company One Medical on February 22, 2023 for 4 billion dollars.


**a)** -- 2 billion + 10 billion + 4 billion.

**b)** + 4 billion.

**c)** + 10 billion + 4 billion.

**d)** + 10 billion.

**e)** None of the above.
"""

# ╔═╡ 570a64b5-f068-4d02-8196-97798a3f2d35
@bind q20 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 9b1a6a58-4bd8-4fb4-ab09-d693a4c5270e
md"""
!!! note "Exercise 9: demand vs supply in a market economy"
 
	As you have studied in introductory microeconomics, price adjustments are the mechanism that equilibrates markets. The following figure illustrates the interaction between supply and demand in a market economy that leads to such adjustments.

	What kind of information can we get by looking at points 1 and 1'? And what happens in the case of points 2 and 2'?

"""

# ╔═╡ d514ab51-c31c-4781-b7f2-00f308a883ab
begin
	Q = 0.0 : 0.05 : 25.0
	Pˢ = 0.0 .+ 0.75 .* Q
	Pᵈ = 18.0 .- 0.75 .* Q

	trace9a = scatter(; x = Q, y = Pᵈ,  mode="lines" , line_color = "maroon", line_width = "2.2",	name  = "Qᵈ")
	
	trace9b = scatter(; x = Q, y = Pˢ, mode="lines" , line_color = "Blue", line_width = "2.2",	name  = "Qˢ")


	trace4_2 = scatter(; x =[11.0 , 13.0],  y = [8.25 , 8.25], text =["1", "1'"], textposition = "top center", 
                    name ="", mode="markers+text", marker_size= "11", marker_color="purple", showlegend = false, 		 					hoverinfo="skip", textfont = attr(family="sans serif", size=16, color="black"))

	trace4_3 = scatter(; x =[11.0 , 13.0],  y = [9.75 , 9.75], text =["2", "2'"], textposition = "top center", 
                    name ="", mode="markers+text", marker_size= "11", marker_color="darkorange", showlegend = false, 		 					hoverinfo="skip", textfont = attr(family="sans serif", size=16, color="black"))
	
		
	layout9 = Layout(;
					height = 450,
					title_text ="Demand (Qᵈ) versus supply (Qˢ)",
					title_x = 0.5,
					hovermode = "y",
                    xaxis=attr(title="Quantity", showgrid=true, zeroline=false),
                    xaxis_range = [9.0, 15.0],	
                    yaxis=attr(title="Price", zeroline = false),
					yaxis_range=[6.5 , 11.5]
	)

   fig9 = plot([trace9a, trace9b, trace4_2 , trace4_3], layout9)	
end

# ╔═╡ 7d0fa09c-6490-49ad-a5ea-a480a7d0036c
md"""
!!! tip "Answer"

	Points 1 and 1' tell us that for the price level of 8.25, there is an excess of demand: $Q^d = 13>Q^s=11$. This excess of demand will force the price level to increase.

	Points 2 and 2' tell us that for the price level of 9.75, there is an excess of supply: $Q^d = 11<Q^s=13$. This excess of supply will force the price level to come down.

	The price will be stable when there is no excess of supply or demand. This occurs if the price is 9 and the quantities demanded and supplied are 12.

"""

# ╔═╡ 24236c6d-64cd-48be-bed8-8c149d1848a3
md"""
____________________________________________________________________________________________________________
"""

# ╔═╡ 4109af60-6178-4148-8efe-890245077188
md"""
## 5. Using linear algebra 
"""

# ╔═╡ 87b575b9-89e4-4c8a-91b0-8e10651909cf
md"""
!!! warning

	In computation, there is a crucial difference between a `,` and a `.`. Therefore, do not forget that $1/2=0.5$, NOT $1/2=0,5$. If you mistakenly use a `,` to express decimal units, you will create a problem your computer does not know how to solve.

"""

# ╔═╡ 3a6c700f-148b-4fff-aa3e-7d20f3bc714a
A = [1 2 3 ; 4 1 6 ; 7 8 1]

# ╔═╡ c582f490-048b-4ecc-b3fe-918d623eaeae
inv(A) # the inverse of A

# ╔═╡ 09d8edd6-9d23-4af9-b8eb-3ded6c961621
transpose(A) # the transpose of A can also be written as A'

# ╔═╡ a23f4a73-bfd8-41ae-9b65-67c8e3e7bec0
B = [α ; β ; 10] # a vector 3x1

# ╔═╡ d93094ca-4912-406a-a573-83887ec40848
det(A) # the determinant of Bia

# ╔═╡ 38851f55-d1af-40f7-a660-62bceec4093a
A*B 

# ╔═╡ eaf75283-c222-46ef-a5ef-9bf9a6a94b75
A^3

# ╔═╡ a4f98b1b-cbb9-4dab-9e84-eba5fcd25c42
zed = randn(3, 3)

# ╔═╡ 3850481f-94b1-4e34-ac43-a346ec70b038
apple = A * zed


# ╔═╡ 291bfa24-a5f1-4505-83c1-b03f838b74de
md"""
!!! note "Exercise 10"
 
	Let us create a matrix of dimension (100x100), with all its elements as randomly generated numbers. Give this matrix a funny name shrek: 	`shrek = randn(10,10)`

	Calculate the inverse of shrek. How long does it take your computer to calculate such an inverse matrix?
"""

# ╔═╡ b95ebf4c-e27e-4768-9473-cb6346f7ef03
begin
	shrek = randn(10,10)
	inv(shrek)
end

# ╔═╡ 183d31a2-781a-4fb3-b6e8-c5f9f24ae8d8
md"""
!!! tip "Answer"

	It takes around 300μs (almost no time at all) to perform the inverse of shrek. 

"""

# ╔═╡ 839efccb-0a96-4cd1-b98f-981017eb2de2
md"""
____________________________________________________________________________________________________________
"""

# ╔═╡ 6460431a-c536-4a0b-8da5-c9e855bddd5a
md"""
## 6. Solving a complicated model
"""

# ╔═╡ fbac12bb-3a2f-4767-ba4d-5786b2285a25
md"""
!!! note "Exercise 11"
 
	Consider the following prototype of a macroeconomic model:

	$\begin{aligned}
	& y_{1} = a + 0.5 y_{2} - 2.5 y_{3} \\
	& y_{2} = -2 y_{1} + 5 y_{3} + b \\
	& y_{3} = 10 y_{1} + 2 c \\
	& a = 10 \ , \ b=2 \ , \ c=5
	\end{aligned}$

	Let us solve this model using the package `NLsolve`. The first thing we should do is to pass the values of the variables with known values to the notebook: $a=10,b=2,c=5$: 

"""

# ╔═╡ ee99589f-9794-49e8-bccd-0a580f489860
a = 10 ; b = 2 ; c = 5 ;  		# the data is passed to the notebook

# ╔═╡ 3af336b8-decb-4608-bdfe-5ba43e0e3b43
md"""
The first thing we have to is to write our model as an homegeneous system (zeros on its left hand side)

$$\begin{aligned}
&0=a+0.5 y_2-2.5 y_3 -y_1 \\
&0=-2 y_1+5 y_3+b -y_2 \\
&0=10 y_1+2 c - y_3
\end{aligned}$$
"""

# ╔═╡ e99f49c6-8ecf-4519-868d-5b76ee13e658
md"""
Then, we have to have to write down our problem according to the syntax of NLsolve: 

					Name, Variables, Functions, Solution

- **Name**. Give a name for our problem. Let us name it as _shrek _ problem_

- **Variables**. Define the variables in our problem: v[1], v[2], v[3] 

- **Functions**. Define the functions in our problem: F[1], F[2], F[3] 

- **Solution**. Compute the solution according to the syntax of NLsolve 

  - Give a name to the solution to our problem: let us name it as _shrek _ solution_

  - Call the NLsolve function that will solve the problem (always this one): _nlsolve_ 

  - Choose the problem to be solved (in this case, is _shrek _ problem_), 

  - Give three initial guesses for the package to start the computation. 

    - For linear problems $[0.0 \ ; 0.0 \ ; 0.0]$ always works. 

  - The number of initial guesses must equal the number of unknowns in the model.

In the image below, we provide a detailed step-by-step explanation of how the solution to the problem above is implemented.
"""

# ╔═╡ 945a400a-2d0d-4075-a26c-e7d6e7899a69
Resource("http://modernmacro.org/resources/Vivaldo/figures/NLsolve_explained.png", :width=>820)

# ╔═╡ 7b2a274a-ee89-4bd7-a61a-eb9c97c7b548
begin
	#defining my problem
	function shrek_problem(F, v)

		# defining variables
		y1 = v[1] 
        y2 = v[2] 
		y3 = v[3] 

		# deining functions
        F[1] = a + 0.5y2 - 2.5y3 - y1
        F[2] = -2y1 + 5y3 + b - y2
		F[3] = 10y1 + 2c - y3 		
	end

	# computing the solution
	shrek_solution = nlsolve(shrek_problem, [0.0 ; 0.0 ; 0.0])		# computes the solution to the problem 
	shrek_solution.zero  											# rounds off the solution
end

# ╔═╡ a0468b27-1df3-4661-baec-e7adb42f281e
md"""
!!! tip "Answer"

	The solution is: y1 = 5.5, y2 = 316, y3 = 65.

"""

# ╔═╡ 02738dfd-8dc3-4396-be73-6242df0f5234
md"""
____________________________________________________________________________________________________________
"""

# ╔═╡ edbd2b1c-1452-41a6-962c-3434bd420020
md"""
## Auxiliary cells (do not change them)
"""

# ╔═╡ d9672a6f-97af-43d1-9a30-50495204fec8
 TableOfContents()

# ╔═╡ 74243a72-0ac6-475e-8134-a9f691524099
#PlotlyKaleido.start();  force_pluto_mathjax_local(true) ; PlotlyKaleido.start(;mathjax = true)

# ╔═╡ 37e34e48-c2a7-4ffd-ac97-1a6ecb44ea92
begin
	
	# Demand	
	Ā = 8.0 ; λ = 0.5 ; m = 2.0 ; ϕ = 0.2 ;	r̄ = 2.0 
	
	# Supply	
	γ  = 2.8 ; Yᴾ = 14.8 ; πᵉ = 2.0 ; ρ  = 0.0
	
end;

# ╔═╡ c564fbd3-79a7-44eb-85fa-1e3ae565949d
function tchanã(ans::Union{Nothing,String},correct::String)	
	if typeof(ans) == Nothing
		md"""
		👆 *Please, select the correct answer.*
		
		---
		"""
	else
		if ans == correct
			md"""
			!!! tip "🎉 Corret!"

			---
			"""
		else	
			md"""
			!!! danger "👎 Wrong answer"
				
				Try again. **But it is better to study first!!!** 😡

			---
			"""
		end
	end
end;

# ╔═╡ 675932ae-9617-4ba4-be26-7a46745c5d44
tchanã(q20,"d)")

# ╔═╡ 60bfcb11-0250-4677-bea1-e47151000d41
md"### CSS code"

# ╔═╡ 98869c8a-3ed6-4042-ba8c-02b1d8225846
html"""
<style>
	@media screen {
		main {
			margin: 0 auto;
			max-width: 1550px;
    		padding-left: max(200px, 10%);
    		padding-right: max(383px, 10%); 
            # 383px to accomodate TableOfContents(aside=true)
		}
	}
 form {
            text-align: center;
            width: fit-content;
            padding: 10px; 
            border: 5px solid #ebebeb;
            margin: 1em 0 2.5em 0;
            border-radius: 25px;
            background: #ebebeb;
            color:#1f1f1f;
      }
      form > div {
            display: inline-block;
            margin-left: 0.75em;
            margin-right: 0.75em;
            font-weight: bold;
      }
</style>
"""

# ╔═╡ 756b03e3-f745-48f6-bf5b-7c0f0d5d7c2f
begin
      struct TwoColumns{L, R}
    left::L
    right::R
      end
      
      function Base.show(io, mime::MIME"text/html", tc::TwoColumns)
          write(io, """<div style="display: flex;"><div style="flex: 20%;margin-left:19%;">""")
          show(io, mime, tc.left)
          write(io, """</div><div style="flex: 20%;">""")
          show(io, mime, tc.right)
          write(io, """</div></div>""")
      end
end

# ╔═╡ 703ca971-86d4-40bf-9118-44468662953d
TwoColumns(
    md"""
    ΔĀ = $(@bind ΔĀ Slider(-1.0:0.05:1.0, default=0.0, show_value=true))
    """,
    md"""
    ΔYᴾ = $(@bind ΔYᴾ Slider(-1.0:0.05:1.0, default=0.0, show_value=true))
    """
)

# ╔═╡ ebdcf47f-1328-4f35-b068-98f300708f06
begin
	Y = 1.8:0.01:15.6

	πᵈ = (1.0 ./(m .* ϕ .* λ)).*(m.* Ā- (m .* ϕ .* r̄) .- Y) 				# AD function
	πˢ = πᵉ .- γ .* (Yᴾ .+ ΔYᴾ) .+ ρ .+ γ .* Y            					# AS function
	
	trace9_0 = scatter(; x = [14.8 .+ ΔYᴾ , 14.8 .+ ΔYᴾ] , y = [-5,10] , 
			mode = "line", line_width = "4", name = "Yp", line_color = "Orange")
	
	trace9_1 = scatter(; x = Y, y = πᵈ, mode="lines" , line_color = "Blue", line_width = "",
			name  = "AD")
	
	trace9_2 = scatter(; x = Y, y = πˢ, mode="lines" , line_color = "Red", line_width = "",
					name  = "AS")
	
	trace9_3 = scatter(; x = [14.8], y = [2.0], text =["1"], 
					textposition = "top center", name ="Eq1", mode="markers+text", marker_size= "12",
					marker_color="Blue", textcolor = "Black",
	 				textfont = attr(family="sans serif", size=18, color="black"))	
	

	πᵈ_ΔĀ = (1.0 ./(m .* ϕ .* λ)).*(m.* (Ā .+ ΔĀ) .- (m .* ϕ .* r̄) .- Y) 			# New AD function
	
	
	trace9_4 = scatter(; x = Y, y = πᵈ_ΔĀ, mode="lines" , line_color = "Magenta", 
					 line_width = "", name  = "AD2")
		
	layout9_5 = Layout(;
					height = 450,
					title_text ="Initial long-term equilibrium",
					title_x = 0.5,
					hovermode = "x",
                    xaxis=attr(title=" GDP trillion dollars (Y)", showgrid=true, zeroline=false),
                    xaxis_range = [14.2, 15.4],	
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[-0.8 , 5])

   fig0 = plot([trace9_0, trace9_1, trace9_2, trace9_4, trace9_3], layout9_5)	
	
end

# ╔═╡ 58abfd26-fc37-4064-b38a-87f74d3164f7
TwoColumns(
	
md"""

`frequency: `$(@bind frequency Slider(0.0:0.1:5.0, default=1.0, show_value=true))

""",
	
md"""

`damping:  `$(@bind damping Slider(-0.5:0.01:0.8, default=0.0, show_value=true))

"""
)

# ╔═╡ 593c6f61-9850-400e-917e-abeec3f06d97
begin
	τ=1:0.01:20
	plot(τ, (exp.(.-damping * τ) .* sin.(frequency .* τ)), Layout(height = 450))
end

# ╔═╡ 00000000-0000-0000-0000-000000000001
PLUTO_PROJECT_TOML_CONTENTS = """
[deps]
CSV = "336ed68f-0bac-5ca0-87d4-7b16caf5d00b"
DataFrames = "a93c6f00-e57d-5684-b7b6-d8193f3e46c0"
Dates = "ade2ca70-3891-5945-98fb-dc099432e06a"
HypertextLiteral = "ac1192a8-f4b3-4bfe-ba22-af5b92cd3ab2"
LinearAlgebra = "37e2e46d-f89d-539d-b4ee-838fcccc9c8e"
NLsolve = "2774e3e8-f4cf-5e23-947b-6d7e65073b56"
PlotlyKaleido = "f2990250-8cf9-495f-b13a-cce12b45703c"
PlutoPlotly = "8e989ff0-3d88-8e9f-f020-2b208a939ff0"
PlutoUI = "7f904dfe-b85e-4ff6-b463-dae2292396a8"
Statistics = "10745b16-79ce-11e8-11f9-7d13ad32a3b2"

[compat]
CSV = "~0.10.4"
DataFrames = "~1.3.4"
HypertextLiteral = "~0.9.5"
NLsolve = "~4.5.1"
PlotlyKaleido = "~2.2.4"
PlutoPlotly = "~0.6.2"
PlutoUI = "~0.7.40"
Statistics = "~1.11.1"
"""

# ╔═╡ 00000000-0000-0000-0000-000000000002
PLUTO_MANIFEST_TOML_CONTENTS = """
# This file is machine-generated - editing it directly is not advised

julia_version = "1.11.3"
manifest_format = "2.0"
project_hash = "8844841cc4676ec2f9f62a333fa6607584554f43"

[[deps.AbstractPlutoDingetjes]]
deps = ["Pkg"]
git-tree-sha1 = "6e1d2a35f2f90a4bc7c2ed98079b2ba09c35b83a"
uuid = "6e696c72-6542-2067-7265-42206c756150"
version = "1.3.2"

[[deps.Adapt]]
deps = ["LinearAlgebra", "Requires"]
git-tree-sha1 = "50c3c56a52972d78e8be9fd135bfb91c9574c140"
uuid = "79e6a3ab-5dfb-504d-930d-738a2a938a0e"
version = "4.1.1"

    [deps.Adapt.extensions]
    AdaptStaticArraysExt = "StaticArrays"

    [deps.Adapt.weakdeps]
    StaticArrays = "90137ffa-7385-5640-81b9-e52037218182"

[[deps.ArgTools]]
uuid = "0dad84c5-d112-42e6-8d28-ef12dabb789f"
version = "1.1.2"

[[deps.ArrayInterface]]
deps = ["Adapt", "LinearAlgebra"]
git-tree-sha1 = "017fcb757f8e921fb44ee063a7aafe5f89b86dd1"
uuid = "4fba245c-0d91-5ea0-9b3e-6abc04ee57a9"
version = "7.18.0"

    [deps.ArrayInterface.extensions]
    ArrayInterfaceBandedMatricesExt = "BandedMatrices"
    ArrayInterfaceBlockBandedMatricesExt = "BlockBandedMatrices"
    ArrayInterfaceCUDAExt = "CUDA"
    ArrayInterfaceCUDSSExt = "CUDSS"
    ArrayInterfaceChainRulesCoreExt = "ChainRulesCore"
    ArrayInterfaceChainRulesExt = "ChainRules"
    ArrayInterfaceGPUArraysCoreExt = "GPUArraysCore"
    ArrayInterfaceReverseDiffExt = "ReverseDiff"
    ArrayInterfaceSparseArraysExt = "SparseArrays"
    ArrayInterfaceStaticArraysCoreExt = "StaticArraysCore"
    ArrayInterfaceTrackerExt = "Tracker"

    [deps.ArrayInterface.weakdeps]
    BandedMatrices = "aae01518-5342-5314-be14-df237901396f"
    BlockBandedMatrices = "ffab5731-97b5-5995-9138-79e8c1846df0"
    CUDA = "052768ef-5323-5732-b1bb-66c8b64840ba"
    CUDSS = "45b445bb-4962-46a0-9369-b4df9d0f772e"
    ChainRules = "082447d4-558c-5d27-93f4-14fc19e9eca2"
    ChainRulesCore = "d360d2e6-b24c-11e9-a2a3-2a2ae2dbcce4"
    GPUArraysCore = "46192b85-c4d5-4398-a991-12ede77f4527"
    ReverseDiff = "37e2e3b7-166d-5795-8a7a-e32c996b4267"
    SparseArrays = "2f01184e-e22b-5df5-ae63-d93ebab69eaf"
    StaticArraysCore = "1e83bf80-4336-4d27-bf5d-d5a4f845583c"
    Tracker = "9f7883ad-71c0-57eb-9f7f-b5c9e6d3789c"

[[deps.Artifacts]]
uuid = "56f22d72-fd6d-98f1-02f0-08ddc0907c33"
version = "1.11.0"

[[deps.Base64]]
uuid = "2a0f44e3-6c83-55bd-87e4-b1978d98bd5f"
version = "1.11.0"

[[deps.CSV]]
deps = ["CodecZlib", "Dates", "FilePathsBase", "InlineStrings", "Mmap", "Parsers", "PooledArrays", "PrecompileTools", "SentinelArrays", "Tables", "Unicode", "WeakRefStrings", "WorkerUtilities"]
git-tree-sha1 = "deddd8725e5e1cc49ee205a1964256043720a6c3"
uuid = "336ed68f-0bac-5ca0-87d4-7b16caf5d00b"
version = "0.10.15"

[[deps.CodecZlib]]
deps = ["TranscodingStreams", "Zlib_jll"]
git-tree-sha1 = "bce6804e5e6044c6daab27bb533d1295e4a2e759"
uuid = "944b1d66-785c-5afd-91f1-9de20f533193"
version = "0.7.6"

[[deps.ColorSchemes]]
deps = ["ColorTypes", "ColorVectorSpace", "Colors", "FixedPointNumbers", "PrecompileTools", "Random"]
git-tree-sha1 = "26ec26c98ae1453c692efded2b17e15125a5bea1"
uuid = "35d6a980-a343-548e-a6ea-1d62b119f2f4"
version = "3.28.0"

[[deps.ColorTypes]]
deps = ["FixedPointNumbers", "Random"]
git-tree-sha1 = "b10d0b65641d57b8b4d5e234446582de5047050d"
uuid = "3da002f7-5984-5a60-b8a6-cbb66c0b333f"
version = "0.11.5"

[[deps.ColorVectorSpace]]
deps = ["ColorTypes", "FixedPointNumbers", "LinearAlgebra", "Requires", "Statistics", "TensorCore"]
git-tree-sha1 = "a1f44953f2382ebb937d60dafbe2deea4bd23249"
uuid = "c3611d14-8923-5661-9e6a-0046d554d3a4"
version = "0.10.0"
weakdeps = ["SpecialFunctions"]

    [deps.ColorVectorSpace.extensions]
    SpecialFunctionsExt = "SpecialFunctions"

[[deps.Colors]]
deps = ["ColorTypes", "FixedPointNumbers", "Reexport"]
git-tree-sha1 = "362a287c3aa50601b0bc359053d5c2468f0e7ce0"
uuid = "5ae59095-9a9b-59fe-a467-6f913c188581"
version = "0.12.11"

[[deps.CommonSubexpressions]]
deps = ["MacroTools"]
git-tree-sha1 = "cda2cfaebb4be89c9084adaca7dd7333369715c5"
uuid = "bbf7d656-a473-5ed7-a52c-81e309532950"
version = "0.3.1"

[[deps.Compat]]
deps = ["TOML", "UUIDs"]
git-tree-sha1 = "8ae8d32e09f0dcf42a36b90d4e17f5dd2e4c4215"
uuid = "34da2185-b29b-5c13-b0c7-acf172513d20"
version = "4.16.0"
weakdeps = ["Dates", "LinearAlgebra"]

    [deps.Compat.extensions]
    CompatLinearAlgebraExt = "LinearAlgebra"

[[deps.CompilerSupportLibraries_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "e66e0078-7015-5450-92f7-15fbd957f2ae"
version = "1.1.1+0"

[[deps.ConstructionBase]]
git-tree-sha1 = "76219f1ed5771adbb096743bff43fb5fdd4c1157"
uuid = "187b0558-2788-49d3-abe0-74a17ed4e7c9"
version = "1.5.8"

    [deps.ConstructionBase.extensions]
    ConstructionBaseIntervalSetsExt = "IntervalSets"
    ConstructionBaseLinearAlgebraExt = "LinearAlgebra"
    ConstructionBaseStaticArraysExt = "StaticArrays"

    [deps.ConstructionBase.weakdeps]
    IntervalSets = "8197267c-284f-5f27-9208-e0e47529a953"
    LinearAlgebra = "37e2e46d-f89d-539d-b4ee-838fcccc9c8e"
    StaticArrays = "90137ffa-7385-5640-81b9-e52037218182"

[[deps.Crayons]]
git-tree-sha1 = "249fe38abf76d48563e2f4556bebd215aa317e15"
uuid = "a8cc5b0e-0ffa-5ad4-8c14-923d3ee1735f"
version = "4.1.1"

[[deps.DataAPI]]
git-tree-sha1 = "abe83f3a2f1b857aac70ef8b269080af17764bbe"
uuid = "9a962f9c-6df0-11e9-0e5d-c546b8b5ee8a"
version = "1.16.0"

[[deps.DataFrames]]
deps = ["Compat", "DataAPI", "Future", "InvertedIndices", "IteratorInterfaceExtensions", "LinearAlgebra", "Markdown", "Missings", "PooledArrays", "PrettyTables", "Printf", "REPL", "Reexport", "SortingAlgorithms", "Statistics", "TableTraits", "Tables", "Unicode"]
git-tree-sha1 = "db2a9cb664fcea7836da4b414c3278d71dd602d2"
uuid = "a93c6f00-e57d-5684-b7b6-d8193f3e46c0"
version = "1.3.6"

[[deps.DataStructures]]
deps = ["Compat", "InteractiveUtils", "OrderedCollections"]
git-tree-sha1 = "1d0a14036acb104d9e89698bd408f63ab58cdc82"
uuid = "864edb3b-99cc-5e75-8d2d-829cb0a9cfe8"
version = "0.18.20"

[[deps.DataValueInterfaces]]
git-tree-sha1 = "bfc1187b79289637fa0ef6d4436ebdfe6905cbd6"
uuid = "e2d170a0-9d28-54be-80f0-106bbe20a464"
version = "1.0.0"

[[deps.Dates]]
deps = ["Printf"]
uuid = "ade2ca70-3891-5945-98fb-dc099432e06a"
version = "1.11.0"

[[deps.DelimitedFiles]]
deps = ["Mmap"]
git-tree-sha1 = "9e2f36d3c96a820c678f2f1f1782582fcf685bae"
uuid = "8bb1440f-4735-579b-a4ab-409b98df4dab"
version = "1.9.1"

[[deps.DiffResults]]
deps = ["StaticArraysCore"]
git-tree-sha1 = "782dd5f4561f5d267313f23853baaaa4c52ea621"
uuid = "163ba53b-c6d8-5494-b064-1a9d43ac40c5"
version = "1.1.0"

[[deps.DiffRules]]
deps = ["IrrationalConstants", "LogExpFunctions", "NaNMath", "Random", "SpecialFunctions"]
git-tree-sha1 = "23163d55f885173722d1e4cf0f6110cdbaf7e272"
uuid = "b552c78f-8df3-52c6-915a-8e097449b14b"
version = "1.15.1"

[[deps.Distances]]
deps = ["LinearAlgebra", "Statistics", "StatsAPI"]
git-tree-sha1 = "c7e3a542b999843086e2f29dac96a618c105be1d"
uuid = "b4f34e82-e78d-54a5-968a-f98e89d6e8f7"
version = "0.10.12"

    [deps.Distances.extensions]
    DistancesChainRulesCoreExt = "ChainRulesCore"
    DistancesSparseArraysExt = "SparseArrays"

    [deps.Distances.weakdeps]
    ChainRulesCore = "d360d2e6-b24c-11e9-a2a3-2a2ae2dbcce4"
    SparseArrays = "2f01184e-e22b-5df5-ae63-d93ebab69eaf"

[[deps.Distributed]]
deps = ["Random", "Serialization", "Sockets"]
uuid = "8ba89e20-285c-5b6f-9357-94700520ee1b"
version = "1.11.0"

[[deps.DocStringExtensions]]
deps = ["LibGit2"]
git-tree-sha1 = "2fb1e02f2b635d0845df5d7c167fec4dd739b00d"
uuid = "ffbed154-4ef7-542d-bbb7-c09d3a79fcae"
version = "0.9.3"

[[deps.Downloads]]
deps = ["ArgTools", "FileWatching", "LibCURL", "NetworkOptions"]
uuid = "f43a241f-c20a-4ad4-852c-f6b1247861c6"
version = "1.6.0"

[[deps.FilePathsBase]]
deps = ["Compat", "Dates"]
git-tree-sha1 = "7878ff7172a8e6beedd1dea14bd27c3c6340d361"
uuid = "48062228-2e41-5def-b9a4-89aafe57970f"
version = "0.9.22"
weakdeps = ["Mmap", "Test"]

    [deps.FilePathsBase.extensions]
    FilePathsBaseMmapExt = "Mmap"
    FilePathsBaseTestExt = "Test"

[[deps.FileWatching]]
uuid = "7b1f6079-737a-58dc-b8bc-7a2ca5c1b5ee"
version = "1.11.0"

[[deps.FiniteDiff]]
deps = ["ArrayInterface", "LinearAlgebra", "Setfield"]
git-tree-sha1 = "f089ab1f834470c525562030c8cfde4025d5e915"
uuid = "6a86dc24-6348-571c-b903-95158fe2bd41"
version = "2.27.0"

    [deps.FiniteDiff.extensions]
    FiniteDiffBandedMatricesExt = "BandedMatrices"
    FiniteDiffBlockBandedMatricesExt = "BlockBandedMatrices"
    FiniteDiffSparseArraysExt = "SparseArrays"
    FiniteDiffStaticArraysExt = "StaticArrays"

    [deps.FiniteDiff.weakdeps]
    BandedMatrices = "aae01518-5342-5314-be14-df237901396f"
    BlockBandedMatrices = "ffab5731-97b5-5995-9138-79e8c1846df0"
    SparseArrays = "2f01184e-e22b-5df5-ae63-d93ebab69eaf"
    StaticArrays = "90137ffa-7385-5640-81b9-e52037218182"

[[deps.FixedPointNumbers]]
deps = ["Statistics"]
git-tree-sha1 = "05882d6995ae5c12bb5f36dd2ed3f61c98cbb172"
uuid = "53c48c17-4a7d-5ca2-90c5-79b7896eea93"
version = "0.8.5"

[[deps.Formatting]]
deps = ["Logging", "Printf"]
git-tree-sha1 = "fb409abab2caf118986fc597ba84b50cbaf00b87"
uuid = "59287772-0a20-5a39-b81b-1366585eb4c0"
version = "0.4.3"

[[deps.ForwardDiff]]
deps = ["CommonSubexpressions", "DiffResults", "DiffRules", "LinearAlgebra", "LogExpFunctions", "NaNMath", "Preferences", "Printf", "Random", "SpecialFunctions"]
git-tree-sha1 = "a2df1b776752e3f344e5116c06d75a10436ab853"
uuid = "f6369f11-7733-5829-9624-2563aa707210"
version = "0.10.38"

    [deps.ForwardDiff.extensions]
    ForwardDiffStaticArraysExt = "StaticArrays"

    [deps.ForwardDiff.weakdeps]
    StaticArrays = "90137ffa-7385-5640-81b9-e52037218182"

[[deps.Future]]
deps = ["Random"]
uuid = "9fa8497b-333b-5362-9e8d-4d0656e87820"
version = "1.11.0"

[[deps.HashArrayMappedTries]]
git-tree-sha1 = "2eaa69a7cab70a52b9687c8bf950a5a93ec895ae"
uuid = "076d061b-32b6-4027-95e0-9a2c6f6d7e74"
version = "0.2.0"

[[deps.Hyperscript]]
deps = ["Test"]
git-tree-sha1 = "179267cfa5e712760cd43dcae385d7ea90cc25a4"
uuid = "47d2ed2b-36de-50cf-bf87-49c2cf4b8b91"
version = "0.0.5"

[[deps.HypertextLiteral]]
deps = ["Tricks"]
git-tree-sha1 = "7134810b1afce04bbc1045ca1985fbe81ce17653"
uuid = "ac1192a8-f4b3-4bfe-ba22-af5b92cd3ab2"
version = "0.9.5"

[[deps.IOCapture]]
deps = ["Logging", "Random"]
git-tree-sha1 = "b6d6bfdd7ce25b0f9b2f6b3dd56b2673a66c8770"
uuid = "b5f81e59-6552-4d32-b1f0-c071b021bf89"
version = "0.2.5"

[[deps.InlineStrings]]
git-tree-sha1 = "45521d31238e87ee9f9732561bfee12d4eebd52d"
uuid = "842dd82b-1e85-43dc-bf29-5d0ee9dffc48"
version = "1.4.2"

    [deps.InlineStrings.extensions]
    ArrowTypesExt = "ArrowTypes"
    ParsersExt = "Parsers"

    [deps.InlineStrings.weakdeps]
    ArrowTypes = "31f734f8-188a-4ce0-8406-c8a06bd891cd"
    Parsers = "69de0a69-1ddd-5017-9359-2bf0b02dc9f0"

[[deps.InteractiveUtils]]
deps = ["Markdown"]
uuid = "b77e0a4c-d291-57a0-90e8-8db25a27a240"
version = "1.11.0"

[[deps.InvertedIndices]]
git-tree-sha1 = "6da3c4316095de0f5ee2ebd875df8721e7e0bdbe"
uuid = "41ab1584-1d38-5bbf-9106-f11c6c58b48f"
version = "1.3.1"

[[deps.IrrationalConstants]]
git-tree-sha1 = "e2222959fbc6c19554dc15174c81bf7bf3aa691c"
uuid = "92d709cd-6900-40b7-9082-c6be49f344b6"
version = "0.2.4"

[[deps.IteratorInterfaceExtensions]]
git-tree-sha1 = "a3f24677c21f5bbe9d2a714f95dcd58337fb2856"
uuid = "82899510-4779-5014-852e-03e436cf321d"
version = "1.0.0"

[[deps.JLLWrappers]]
deps = ["Artifacts", "Preferences"]
git-tree-sha1 = "a007feb38b422fbdab534406aeca1b86823cb4d6"
uuid = "692b3bcd-3c85-4b1f-b108-f13ce0eb3210"
version = "1.7.0"

[[deps.JSON]]
deps = ["Dates", "Mmap", "Parsers", "Unicode"]
git-tree-sha1 = "31e996f0a15c7b280ba9f76636b3ff9e2ae58c9a"
uuid = "682c06a0-de6a-54ab-a142-c8b1cf79cde6"
version = "0.21.4"

[[deps.Kaleido_jll]]
deps = ["Artifacts", "JLLWrappers", "Libdl", "Pkg"]
git-tree-sha1 = "43032da5832754f58d14a91ffbe86d5f176acda9"
uuid = "f7e6163d-2fa5-5f23-b69c-1db539e41963"
version = "0.2.1+0"

[[deps.LaTeXStrings]]
git-tree-sha1 = "dda21b8cbd6a6c40d9d02a73230f9d70fed6918c"
uuid = "b964fa9f-0449-5b57-a5c2-d3ea65f4040f"
version = "1.4.0"

[[deps.LibCURL]]
deps = ["LibCURL_jll", "MozillaCACerts_jll"]
uuid = "b27032c2-a3e7-50c8-80cd-2d36dbcbfd21"
version = "0.6.4"

[[deps.LibCURL_jll]]
deps = ["Artifacts", "LibSSH2_jll", "Libdl", "MbedTLS_jll", "Zlib_jll", "nghttp2_jll"]
uuid = "deac9b47-8bc7-5906-a0fe-35ac56dc84c0"
version = "8.6.0+0"

[[deps.LibGit2]]
deps = ["Base64", "LibGit2_jll", "NetworkOptions", "Printf", "SHA"]
uuid = "76f85450-5226-5b5a-8eaa-529ad045b433"
version = "1.11.0"

[[deps.LibGit2_jll]]
deps = ["Artifacts", "LibSSH2_jll", "Libdl", "MbedTLS_jll"]
uuid = "e37daf67-58a4-590a-8e99-b0245dd2ffc5"
version = "1.7.2+0"

[[deps.LibSSH2_jll]]
deps = ["Artifacts", "Libdl", "MbedTLS_jll"]
uuid = "29816b5a-b9ab-546f-933c-edad1886dfa8"
version = "1.11.0+1"

[[deps.Libdl]]
uuid = "8f399da3-3557-5675-b5ff-fb832c97cbdb"
version = "1.11.0"

[[deps.LineSearches]]
deps = ["LinearAlgebra", "NLSolversBase", "NaNMath", "Parameters", "Printf"]
git-tree-sha1 = "e4c3be53733db1051cc15ecf573b1042b3a712a1"
uuid = "d3d80556-e9d4-5f37-9878-2ab0fcc64255"
version = "7.3.0"

[[deps.LinearAlgebra]]
deps = ["Libdl", "OpenBLAS_jll", "libblastrampoline_jll"]
uuid = "37e2e46d-f89d-539d-b4ee-838fcccc9c8e"
version = "1.11.0"

[[deps.LogExpFunctions]]
deps = ["DocStringExtensions", "IrrationalConstants", "LinearAlgebra"]
git-tree-sha1 = "13ca9e2586b89836fd20cccf56e57e2b9ae7f38f"
uuid = "2ab3a3ac-af41-5b50-aa03-7779005ae688"
version = "0.3.29"

    [deps.LogExpFunctions.extensions]
    LogExpFunctionsChainRulesCoreExt = "ChainRulesCore"
    LogExpFunctionsChangesOfVariablesExt = "ChangesOfVariables"
    LogExpFunctionsInverseFunctionsExt = "InverseFunctions"

    [deps.LogExpFunctions.weakdeps]
    ChainRulesCore = "d360d2e6-b24c-11e9-a2a3-2a2ae2dbcce4"
    ChangesOfVariables = "9e997f8a-9a97-42d5-a9f1-ce6bfc15e2c0"
    InverseFunctions = "3587e190-3f89-42d0-90ee-14403ec27112"

[[deps.Logging]]
uuid = "56ddb016-857b-54e1-b83d-db4d58db5568"
version = "1.11.0"

[[deps.MIMEs]]
git-tree-sha1 = "1833212fd6f580c20d4291da9c1b4e8a655b128e"
uuid = "6c6e2e6c-3030-632d-7369-2d6c69616d65"
version = "1.0.0"

[[deps.MacroTools]]
git-tree-sha1 = "72aebe0b5051e5143a079a4685a46da330a40472"
uuid = "1914dd2f-81c6-5fcd-8719-6d5c9610ff09"
version = "0.5.15"

[[deps.Markdown]]
deps = ["Base64"]
uuid = "d6f4376e-aef5-505a-96c1-9c027394607a"
version = "1.11.0"

[[deps.MbedTLS_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "c8ffd9c3-330d-5841-b78e-0817d7145fa1"
version = "2.28.6+0"

[[deps.Missings]]
deps = ["DataAPI"]
git-tree-sha1 = "ec4f7fbeab05d7747bdf98eb74d130a2a2ed298d"
uuid = "e1d29d7a-bbdc-5cf2-9ac0-f12de2c33e28"
version = "1.2.0"

[[deps.Mmap]]
uuid = "a63ad114-7e13-5084-954f-fe012c677804"
version = "1.11.0"

[[deps.MozillaCACerts_jll]]
uuid = "14a3606d-f60d-562e-9121-12d972cd8159"
version = "2023.12.12"

[[deps.NLSolversBase]]
deps = ["DiffResults", "Distributed", "FiniteDiff", "ForwardDiff"]
git-tree-sha1 = "a0b464d183da839699f4c79e7606d9d186ec172c"
uuid = "d41bc354-129a-5804-8e4c-c37616107c6c"
version = "7.8.3"

[[deps.NLsolve]]
deps = ["Distances", "LineSearches", "LinearAlgebra", "NLSolversBase", "Printf", "Reexport"]
git-tree-sha1 = "019f12e9a1a7880459d0173c182e6a99365d7ac1"
uuid = "2774e3e8-f4cf-5e23-947b-6d7e65073b56"
version = "4.5.1"

[[deps.NaNMath]]
deps = ["OpenLibm_jll"]
git-tree-sha1 = "cc0a5deefdb12ab3a096f00a6d42133af4560d71"
uuid = "77ba4419-2d1f-58cd-9bb1-8ffee604a2e3"
version = "1.1.2"

[[deps.NetworkOptions]]
uuid = "ca575930-c2e3-43a9-ace4-1e988b2c1908"
version = "1.2.0"

[[deps.OpenBLAS_jll]]
deps = ["Artifacts", "CompilerSupportLibraries_jll", "Libdl"]
uuid = "4536629a-c528-5b80-bd46-f80d51c5b363"
version = "0.3.27+1"

[[deps.OpenLibm_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "05823500-19ac-5b8b-9628-191a04bc5112"
version = "0.8.1+2"

[[deps.OpenSpecFun_jll]]
deps = ["Artifacts", "CompilerSupportLibraries_jll", "JLLWrappers", "Libdl"]
git-tree-sha1 = "1346c9208249809840c91b26703912dff463d335"
uuid = "efe28fd5-8261-553b-a9e1-b2916fc3738e"
version = "0.5.6+0"

[[deps.OrderedCollections]]
git-tree-sha1 = "cc4054e898b852042d7b503313f7ad03de99c3dd"
uuid = "bac558e1-5e72-5ebc-8fee-abe8a469f55d"
version = "1.8.0"

[[deps.Parameters]]
deps = ["OrderedCollections", "UnPack"]
git-tree-sha1 = "34c0e9ad262e5f7fc75b10a9952ca7692cfc5fbe"
uuid = "d96e819e-fc66-5662-9728-84c9c7592b0a"
version = "0.12.3"

[[deps.Parsers]]
deps = ["Dates", "PrecompileTools", "UUIDs"]
git-tree-sha1 = "8489905bcdbcfac64d1daa51ca07c0d8f0283821"
uuid = "69de0a69-1ddd-5017-9359-2bf0b02dc9f0"
version = "2.8.1"

[[deps.Pkg]]
deps = ["Artifacts", "Dates", "Downloads", "FileWatching", "LibGit2", "Libdl", "Logging", "Markdown", "Printf", "Random", "SHA", "TOML", "Tar", "UUIDs", "p7zip_jll"]
uuid = "44cfe95a-1eb2-52ea-b672-e2afdf69b78f"
version = "1.11.0"
weakdeps = ["REPL"]

    [deps.Pkg.extensions]
    REPLExt = "REPL"

[[deps.PlotlyBase]]
deps = ["ColorSchemes", "Dates", "DelimitedFiles", "DocStringExtensions", "JSON", "LaTeXStrings", "Logging", "Parameters", "Pkg", "REPL", "Requires", "Statistics", "UUIDs"]
git-tree-sha1 = "56baf69781fc5e61607c3e46227ab17f7040ffa2"
uuid = "a03496cd-edff-5a9b-9e67-9cda94a718b5"
version = "0.8.19"

[[deps.PlotlyKaleido]]
deps = ["Artifacts", "Base64", "JSON", "Kaleido_jll"]
git-tree-sha1 = "ba551e47d7eac212864fdfea3bd07f30202b4a5b"
uuid = "f2990250-8cf9-495f-b13a-cce12b45703c"
version = "2.2.6"

[[deps.PlutoPlotly]]
deps = ["AbstractPlutoDingetjes", "Artifacts", "ColorSchemes", "Colors", "Dates", "Downloads", "HypertextLiteral", "InteractiveUtils", "LaTeXStrings", "Markdown", "Pkg", "PlotlyBase", "PrecompileTools", "Reexport", "ScopedValues", "Scratch", "TOML"]
git-tree-sha1 = "9ebe25fc4703d4112cc418834d5e4c9a4b29087d"
uuid = "8e989ff0-3d88-8e9f-f020-2b208a939ff0"
version = "0.6.2"

    [deps.PlutoPlotly.extensions]
    PlotlyKaleidoExt = "PlotlyKaleido"
    UnitfulExt = "Unitful"

    [deps.PlutoPlotly.weakdeps]
    PlotlyKaleido = "f2990250-8cf9-495f-b13a-cce12b45703c"
    Unitful = "1986cc42-f94f-5a68-af5c-568840ba703d"

[[deps.PlutoUI]]
deps = ["AbstractPlutoDingetjes", "Base64", "ColorTypes", "Dates", "FixedPointNumbers", "Hyperscript", "HypertextLiteral", "IOCapture", "InteractiveUtils", "JSON", "Logging", "MIMEs", "Markdown", "Random", "Reexport", "URIs", "UUIDs"]
git-tree-sha1 = "7e71a55b87222942f0f9337be62e26b1f103d3e4"
uuid = "7f904dfe-b85e-4ff6-b463-dae2292396a8"
version = "0.7.61"

[[deps.PooledArrays]]
deps = ["DataAPI", "Future"]
git-tree-sha1 = "36d8b4b899628fb92c2749eb488d884a926614d3"
uuid = "2dfb63ee-cc39-5dd5-95bd-886bf059d720"
version = "1.4.3"

[[deps.PrecompileTools]]
deps = ["Preferences"]
git-tree-sha1 = "5aa36f7049a63a1528fe8f7c3f2113413ffd4e1f"
uuid = "aea7be01-6a6a-4083-8856-8a6e6704d82a"
version = "1.2.1"

[[deps.Preferences]]
deps = ["TOML"]
git-tree-sha1 = "9306f6085165d270f7e3db02af26a400d580f5c6"
uuid = "21216c6a-2e73-6563-6e65-726566657250"
version = "1.4.3"

[[deps.PrettyTables]]
deps = ["Crayons", "Formatting", "Markdown", "Reexport", "Tables"]
git-tree-sha1 = "dfb54c4e414caa595a1f2ed759b160f5a3ddcba5"
uuid = "08abe8d2-0d0c-5749-adfa-8a2ac140af0d"
version = "1.3.1"

[[deps.Printf]]
deps = ["Unicode"]
uuid = "de0858da-6303-5e67-8744-51eddeeeb8d7"
version = "1.11.0"

[[deps.REPL]]
deps = ["InteractiveUtils", "Markdown", "Sockets", "StyledStrings", "Unicode"]
uuid = "3fa0cd96-eef1-5676-8a61-b3b8758bbffb"
version = "1.11.0"

[[deps.Random]]
deps = ["SHA"]
uuid = "9a3f8284-a2c9-5f02-9a11-845980a1fd5c"
version = "1.11.0"

[[deps.Reexport]]
git-tree-sha1 = "45e428421666073eab6f2da5c9d310d99bb12f9b"
uuid = "189a3867-3050-52da-a836-e630ba90ab69"
version = "1.2.2"

[[deps.Requires]]
deps = ["UUIDs"]
git-tree-sha1 = "838a3a4188e2ded87a4f9f184b4b0d78a1e91cb7"
uuid = "ae029012-a4dd-5104-9daa-d747884805df"
version = "1.3.0"

[[deps.SHA]]
uuid = "ea8e919c-243c-51af-8825-aaa63cd721ce"
version = "0.7.0"

[[deps.ScopedValues]]
deps = ["HashArrayMappedTries", "Logging"]
git-tree-sha1 = "1147f140b4c8ddab224c94efa9569fc23d63ab44"
uuid = "7e506255-f358-4e82-b7e4-beb19740aa63"
version = "1.3.0"

[[deps.Scratch]]
deps = ["Dates"]
git-tree-sha1 = "3bac05bc7e74a75fd9cba4295cde4045d9fe2386"
uuid = "6c6a2e73-6563-6170-7368-637461726353"
version = "1.2.1"

[[deps.SentinelArrays]]
deps = ["Dates", "Random"]
git-tree-sha1 = "712fb0231ee6f9120e005ccd56297abbc053e7e0"
uuid = "91c51154-3ec4-41a3-a24f-3f23e20d615c"
version = "1.4.8"

[[deps.Serialization]]
uuid = "9e88b42a-f829-5b0c-bbe9-9e923198166b"
version = "1.11.0"

[[deps.Setfield]]
deps = ["ConstructionBase", "Future", "MacroTools", "StaticArraysCore"]
git-tree-sha1 = "e2cc6d8c88613c05e1defb55170bf5ff211fbeac"
uuid = "efcf1570-3423-57d1-acb7-fd33fddbac46"
version = "1.1.1"

[[deps.Sockets]]
uuid = "6462fe0b-24de-5631-8697-dd941f90decc"
version = "1.11.0"

[[deps.SortingAlgorithms]]
deps = ["DataStructures"]
git-tree-sha1 = "66e0a8e672a0bdfca2c3f5937efb8538b9ddc085"
uuid = "a2af1166-a08f-5f64-846c-94a0d3cef48c"
version = "1.2.1"

[[deps.SpecialFunctions]]
deps = ["IrrationalConstants", "LogExpFunctions", "OpenLibm_jll", "OpenSpecFun_jll"]
git-tree-sha1 = "64cca0c26b4f31ba18f13f6c12af7c85f478cfde"
uuid = "276daf66-3868-5448-9aa4-cd146d93841b"
version = "2.5.0"

    [deps.SpecialFunctions.extensions]
    SpecialFunctionsChainRulesCoreExt = "ChainRulesCore"

    [deps.SpecialFunctions.weakdeps]
    ChainRulesCore = "d360d2e6-b24c-11e9-a2a3-2a2ae2dbcce4"

[[deps.StaticArraysCore]]
git-tree-sha1 = "192954ef1208c7019899fbf8049e717f92959682"
uuid = "1e83bf80-4336-4d27-bf5d-d5a4f845583c"
version = "1.4.3"

[[deps.Statistics]]
deps = ["LinearAlgebra"]
git-tree-sha1 = "ae3bb1eb3bba077cd276bc5cfc337cc65c3075c0"
uuid = "10745b16-79ce-11e8-11f9-7d13ad32a3b2"
version = "1.11.1"

    [deps.Statistics.extensions]
    SparseArraysExt = ["SparseArrays"]

    [deps.Statistics.weakdeps]
    SparseArrays = "2f01184e-e22b-5df5-ae63-d93ebab69eaf"

[[deps.StatsAPI]]
deps = ["LinearAlgebra"]
git-tree-sha1 = "1ff449ad350c9c4cbc756624d6f8a8c3ef56d3ed"
uuid = "82ae8749-77ed-4fe6-ae5f-f523153014b0"
version = "1.7.0"

[[deps.StyledStrings]]
uuid = "f489334b-da3d-4c2e-b8f0-e476e12c162b"
version = "1.11.0"

[[deps.TOML]]
deps = ["Dates"]
uuid = "fa267f1f-6049-4f14-aa54-33bafae1ed76"
version = "1.0.3"

[[deps.TableTraits]]
deps = ["IteratorInterfaceExtensions"]
git-tree-sha1 = "c06b2f539df1c6efa794486abfb6ed2022561a39"
uuid = "3783bdb8-4a98-5b6b-af9a-565f29a5fe9c"
version = "1.0.1"

[[deps.Tables]]
deps = ["DataAPI", "DataValueInterfaces", "IteratorInterfaceExtensions", "OrderedCollections", "TableTraits"]
git-tree-sha1 = "598cd7c1f68d1e205689b1c2fe65a9f85846f297"
uuid = "bd369af6-aec1-5ad0-b16a-f7cc5008161c"
version = "1.12.0"

[[deps.Tar]]
deps = ["ArgTools", "SHA"]
uuid = "a4e569a6-e804-4fa4-b0f3-eef7a1d5b13e"
version = "1.10.0"

[[deps.TensorCore]]
deps = ["LinearAlgebra"]
git-tree-sha1 = "1feb45f88d133a655e001435632f019a9a1bcdb6"
uuid = "62fd8b95-f654-4bbd-a8a5-9c27f68ccd50"
version = "0.1.1"

[[deps.Test]]
deps = ["InteractiveUtils", "Logging", "Random", "Serialization"]
uuid = "8dfed614-e22c-5e08-85e1-65c5234f0b40"
version = "1.11.0"

[[deps.TranscodingStreams]]
git-tree-sha1 = "0c45878dcfdcfa8480052b6ab162cdd138781742"
uuid = "3bb67fe8-82b1-5028-8e26-92a6c54297fa"
version = "0.11.3"

[[deps.Tricks]]
git-tree-sha1 = "6cae795a5a9313bbb4f60683f7263318fc7d1505"
uuid = "410a4b4d-49e4-4fbc-ab6d-cb71b17b3775"
version = "0.1.10"

[[deps.URIs]]
git-tree-sha1 = "67db6cc7b3821e19ebe75791a9dd19c9b1188f2b"
uuid = "5c2747f8-b7ea-4ff2-ba2e-563bfd36b1d4"
version = "1.5.1"

[[deps.UUIDs]]
deps = ["Random", "SHA"]
uuid = "cf7118a7-6976-5b1a-9a39-7adc72f591a4"
version = "1.11.0"

[[deps.UnPack]]
git-tree-sha1 = "387c1f73762231e86e0c9c5443ce3b4a0a9a0c2b"
uuid = "3a884ed6-31ef-47d7-9d2a-63182c4928ed"
version = "1.0.2"

[[deps.Unicode]]
uuid = "4ec0a83e-493e-50e2-b9ac-8f72acf5a8f5"
version = "1.11.0"

[[deps.WeakRefStrings]]
deps = ["DataAPI", "InlineStrings", "Parsers"]
git-tree-sha1 = "b1be2855ed9ed8eac54e5caff2afcdb442d52c23"
uuid = "ea10d353-3f73-51f8-a26c-33c1cb351aa5"
version = "1.4.2"

[[deps.WorkerUtilities]]
git-tree-sha1 = "cd1659ba0d57b71a464a29e64dbc67cfe83d54e7"
uuid = "76eceee3-57b5-4d4a-8e66-0e911cebbf60"
version = "1.6.1"

[[deps.Zlib_jll]]
deps = ["Libdl"]
uuid = "83775a58-1f1d-513f-b197-d71354ab007a"
version = "1.2.13+1"

[[deps.libblastrampoline_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "8e850b90-86db-534c-a0d3-1478176c7d93"
version = "5.11.0+0"

[[deps.nghttp2_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "8e850ede-7688-5339-a07c-302acd2aaf8d"
version = "1.59.0+0"

[[deps.p7zip_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "3f19e933-33d8-53b3-aaab-bd5110c3b7a0"
version = "17.4.0+2"
"""

# ╔═╡ Cell order:
# ╟─49b0122c-eb23-4cab-a49d-077fb76b53df
# ╟─82090c38-1ecd-43eb-aeca-135d996b8e72
# ╟─76164b77-2e0b-4deb-8ef8-1b2263260e7a
# ╟─f5e8df36-5568-48ca-a0f8-d118f49edc6c
# ╟─554b2cc5-99e1-4eda-b080-67ab2eddac16
# ╠═b72215bb-8e3a-46e2-8817-271befe1178c
# ╟─f270f189-2838-4827-9c53-aef5f4f678d4
# ╟─31023dd0-f304-471e-a292-2a40915ebcbf
# ╟─7afb249a-ee89-4874-91fa-6da606948b2a
# ╟─cbaf6be3-ce2e-424f-9eba-2afdb0f024fe
# ╟─86f1359d-3637-4892-9720-e042fae6543a
# ╟─0fc80d2d-6519-4f17-83c4-25ab9b26d8ce
# ╟─16ecc97b-a401-4172-bcbb-b0baa156b53c
# ╟─564ff460-aa1f-4b9d-abf3-a024a13d96a3
# ╟─ca0b5757-4521-4d4b-b46f-76b8dfdc2d62
# ╟─6307472b-3a3e-4d9a-82fd-25d295abaae1
# ╟─638ac59a-6fb2-447f-8856-0c6f74494e7b
# ╟─47c0ad5a-3c9f-4b42-b353-c40ea704f404
# ╟─364250da-5811-4e15-9f88-e408a99e83f3
# ╠═5eaac75d-b7aa-412e-bb73-ed4865cae27b
# ╟─98f18fc3-0748-4ec7-a6a0-955e2ea22e19
# ╟─e81d6184-2b39-4205-83a8-9e2d7e5d41dd
# ╟─70af87bd-81b5-4aa0-b1f7-0639d1f09d0a
# ╟─2da4b605-2d9e-494a-810f-5d153dee7096
# ╟─8c3253f4-86c2-4b88-9850-f7daed87774d
# ╟─dca08890-c8af-4a31-b7cd-bf27e9bd91b7
# ╟─a0280f97-cf3d-4aaf-a013-45d957bd5700
# ╟─5b3d0a21-ab5c-4b41-8824-eae02427a14c
# ╟─dfc08cee-92a3-43dd-a4be-e66a7a3ae4d9
# ╟─847ceec0-33cc-4cf4-a27f-ab7b85944529
# ╟─8f1bb867-1fa7-45e1-9806-70055ae22403
# ╠═4e908c09-f7eb-4698-9e9a-af1b7f7e5dc0
# ╠═eea51a0b-cbe8-4fec-baec-ebc0601374d5
# ╠═731a0394-6dc6-44af-ada7-164fe8ed0c20
# ╠═697cac78-ee49-48b7-9e7e-e6eace68cab9
# ╠═abf827e7-0a9f-45e0-b89e-4b7ebaece273
# ╟─b26522be-2c5e-4cd0-bfa2-eb20ff1f8070
# ╠═f01ee3cf-674b-41e2-8615-aebacb9ba384
# ╟─26c4d01b-729e-4629-90a8-1e91247d0dff
# ╠═44eadb1a-e4e2-4e62-a2b5-c29d11e9dc40
# ╟─9d6a33a0-72c5-4c36-b1be-fa17996ceda9
# ╟─b0ef4ed2-8236-4809-a508-74fee43f4bb2
# ╟─9b622087-ad34-4f19-9929-cbdf0256eae0
# ╟─b8b7733f-d8ea-48d9-a24a-a938dc83f641
# ╟─af94fe17-19e7-418d-90a8-6e76ecfbfb29
# ╟─a1011eff-d753-437a-8139-925cef00f188
# ╠═d4b64810-d65f-45ea-9037-bb2e57ff8811
# ╠═70a5fdbe-17fa-4766-9c30-ab97113507b9
# ╠═e1474fb7-6814-4294-b752-b0156db225f2
# ╠═ee6330b0-efb8-4714-9957-5aeddce0867b
# ╠═975dd1ad-7989-40d1-9374-322da6dde414
# ╠═a4f1fff1-2e34-4b40-81b0-899a5012fb64
# ╠═8325bf62-e34f-429f-9c5a-c3a994e4d6ee
# ╟─7eaf19e5-f205-485d-82a8-48fc1987df33
# ╟─edd2845f-2da7-49b8-a509-f2bfa391c7cb
# ╟─c39ba17f-5894-4bc4-b6aa-f6f39947dc59
# ╟─5b28585a-29ef-4de8-91a9-7dd9fd559515
# ╟─1dfab317-6e41-4c11-a811-683f0fd897b4
# ╟─703ca971-86d4-40bf-9118-44468662953d
# ╟─ebdcf47f-1328-4f35-b068-98f300708f06
# ╟─d06b313f-d6c0-45bc-96f5-7514c9765f81
# ╟─1026f60d-0d2b-465b-a342-5a79af8131eb
# ╟─86249e98-7e54-4e42-a02f-ab5af6120194
# ╟─58abfd26-fc37-4064-b38a-87f74d3164f7
# ╠═593c6f61-9850-400e-917e-abeec3f06d97
# ╟─ca2c2c20-acd6-49bf-b7e0-86590cc12b46
# ╟─98fcb7b2-4d54-4119-a8ea-9545bea129e3
# ╟─4dc03487-e364-43e7-ba4a-e88ac9344089
# ╟─fa2bb866-fac3-481c-837b-a8425fe84160
# ╟─72e56a5d-acf3-494d-b870-7806855eb74c
# ╟─09a44240-57a1-4064-9048-406cf4073cb9
# ╟─cd0cd247-d257-49b1-a43b-f548a6062e36
# ╟─987351ec-a397-4d67-a33f-967cd3464913
# ╟─5045c5ff-6ec3-4d4a-b076-5356c39c3355
# ╠═4930d23c-d101-4c36-b2f6-d6b8ddca1dc0
# ╟─30e9b082-c43d-4f5b-b5bc-c5038e121dc6
# ╟─a11ee5f4-6790-4a96-8ee0-3c6b7ef0198e
# ╠═d2cd2672-83a0-4488-80e9-0c54c064b19d
# ╟─1818b565-dbd0-438b-9a69-0815b8013675
# ╟─22d3f12d-753b-4062-a6ee-53e3af16674a
# ╟─2b457972-3c5d-4421-90df-42c09d0d68c8
# ╟─afca4d98-7fe9-4123-b130-d3f5b3813db0
# ╟─570a64b5-f068-4d02-8196-97798a3f2d35
# ╟─675932ae-9617-4ba4-be26-7a46745c5d44
# ╟─9b1a6a58-4bd8-4fb4-ab09-d693a4c5270e
# ╟─d514ab51-c31c-4781-b7f2-00f308a883ab
# ╟─7d0fa09c-6490-49ad-a5ea-a480a7d0036c
# ╟─24236c6d-64cd-48be-bed8-8c149d1848a3
# ╟─4109af60-6178-4148-8efe-890245077188
# ╟─87b575b9-89e4-4c8a-91b0-8e10651909cf
# ╠═3a6c700f-148b-4fff-aa3e-7d20f3bc714a
# ╠═c582f490-048b-4ecc-b3fe-918d623eaeae
# ╠═09d8edd6-9d23-4af9-b8eb-3ded6c961621
# ╠═a23f4a73-bfd8-41ae-9b65-67c8e3e7bec0
# ╠═d93094ca-4912-406a-a573-83887ec40848
# ╟─38851f55-d1af-40f7-a660-62bceec4093a
# ╠═eaf75283-c222-46ef-a5ef-9bf9a6a94b75
# ╠═a4f98b1b-cbb9-4dab-9e84-eba5fcd25c42
# ╠═3850481f-94b1-4e34-ac43-a346ec70b038
# ╟─291bfa24-a5f1-4505-83c1-b03f838b74de
# ╠═b95ebf4c-e27e-4768-9473-cb6346f7ef03
# ╟─183d31a2-781a-4fb3-b6e8-c5f9f24ae8d8
# ╟─839efccb-0a96-4cd1-b98f-981017eb2de2
# ╟─6460431a-c536-4a0b-8da5-c9e855bddd5a
# ╟─fbac12bb-3a2f-4767-ba4d-5786b2285a25
# ╠═ee99589f-9794-49e8-bccd-0a580f489860
# ╟─3af336b8-decb-4608-bdfe-5ba43e0e3b43
# ╟─e99f49c6-8ecf-4519-868d-5b76ee13e658
# ╟─945a400a-2d0d-4075-a26c-e7d6e7899a69
# ╠═7b2a274a-ee89-4bd7-a61a-eb9c97c7b548
# ╟─a0468b27-1df3-4661-baec-e7adb42f281e
# ╟─02738dfd-8dc3-4396-be73-6242df0f5234
# ╟─edbd2b1c-1452-41a6-962c-3434bd420020
# ╟─d9672a6f-97af-43d1-9a30-50495204fec8
# ╟─74243a72-0ac6-475e-8134-a9f691524099
# ╟─37e34e48-c2a7-4ffd-ac97-1a6ecb44ea92
# ╟─c564fbd3-79a7-44eb-85fa-1e3ae565949d
# ╟─60bfcb11-0250-4677-bea1-e47151000d41
# ╟─98869c8a-3ed6-4042-ba8c-02b1d8225846
# ╟─756b03e3-f745-48f6-bf5b-7c0f0d5d7c2f
# ╟─00000000-0000-0000-0000-000000000001
# ╟─00000000-0000-0000-0000-000000000002
